@@ -342,7 +342,7 @@ function Window(options) {
   });
   const screen = Screen.create(window);
   const crypto = Crypto.create(window);
-  const customElementRegistry = CustomElementRegistry.create(window);
+  this._customElementRegistry = CustomElementRegistry.create(window);
 
   define(this, {
     get length() {
@@ -441,7 +441,7 @@ function Window(options) {
       return this._sessionStorage;
     },
     get customElements() {
-      return customElementRegistry;
+      return this._customElementRegistry;
     },
     get event() {
       return window._currentEvent ? idlUtils.wrapperForImpl(window._currentEvent) : undefined;
